from setuptools import setup

setup(
    name='mir_bootleg_score',
    version='0.1.0',    
    description='Built for MIR Lab. Tools for converting png images into bootleg score features.',
    url='https://github.com/shuds13/pyexample',
    author='Arjun Taneja',
    author_email='ataneja@g.hmc.edu',
    license='BSD 2-clause',
    packages=['mir_bootleg_score'],
    install_requires=[],

    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',  
        'Operating System :: POSIX :: Linux',        
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
    ],
)
